#----------------------------------------------------------------------
# Copyright 1999-2005 Mitel Networks Corporation
# This program is free software; you can redistribute it and/or
# modify it under the same terms as Perl itself.
#----------------------------------------------------------------------

package esmith::ethernet;

#----------------------------------------------------------------------

use strict;

=head1 NAME

esmith::ethernet - Ethernet-related utility routines for e-smith

=head1 VERSION

This file documents C<esmith::ethernet> version B<1.4.0>

=head1 SYNOPSIS

    use esmith::ethernet;

=head1 DESCRIPTION

This module contains routines for 


=pod

=head2 probeAdapters()

Probe for any recognised adapters

=cut

sub probeAdapters ()
{
    my @devs;
    my $r;
    local $ENV{PATH} = "/bin:/sbin:/usr/bin:/usr/sbin";
    unless (open(HWC, "/usr/sbin/kudzu --probe --class network|"))
    {
	warn "Could not run kudzu probe: $!";
	return "";
    }
    while (<HWC>)
    {
	if (/^-/)
	{
	    $r = {};
	    push @devs, $r;
	}
	if (/(.+): (.+)/)
	{
	    $r->{$1} = $2;
	}
    }
    close HWC;
                                                                                                             
    my @nics = grep { $_->{device} && $_->{device} =~ /^eth/ } @devs;
    my $adapters  = '';
    my $index = 1;
    foreach my $nic (@nics)
    {
        $adapters .=
          "EthernetDriver" . $index++ . "\t" . $nic->{driver} . "\t"
          . $nic->{'network.hwaddr'} . "\t" . $nic->{desc} . "\n";
    }
    return $adapters;
}


#----------------------------------------------------------------------
# Return one to make the import process return success.
#----------------------------------------------------------------------

1;

=pod

=AUTHOR

SME Server Developers <bugs@e-smith.com>

For more information see http://www.e-smith.org/

=cut

